/*
 * Copyright (C) 2014, 2016 Stefano Verzegnassi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import Ubuntu.Content 1.3

Page {
    id: picker

    property var activeTransfer

    ContentTransferHint {
        id: transferHint
        anchors.fill: parent
        activeTransfer: picker.activeTransfer
    }

    header: PageHeader {
        title: i18n.tr("Open with...")

        sections.model: [ i18n.tr("Documents"), i18n.tr("Unknown") ]
        leadingActionBar.actions: Action {
            iconName: "close"
            text: i18n.tr("Close")
            onTriggered: Qt.quit()
        }
    }

    ContentPeerPicker {
        showTitle: false
        anchors.topMargin: picker.header.height

        contentType: {
            switch (picker.header.sections.selectedIndex) {
            case 0:
                return ContentType.Documents
            case 1:
                return ContentType.Unknown
            }
        }
        handler: ContentHandler.Source

        onPeerSelected: {
            peer.selectionType = ContentTransfer.Single
            picker.activeTransfer = peer.request(mainView.contentStore);
        }
    }

    Connections {
        target: picker.activeTransfer ? picker.activeTransfer : null
        onStateChanged: {
            if (picker.activeTransfer.state === ContentTransfer.Charged) {
                mainView.openDocument(picker.activeTransfer.items[0].url.toString().replace("file://", ""))
                console.log("[CONTENT-HUB] Content imported!")
            }
        }
    }
}
