/*
 * Copyright (C) 2013-2015 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import Ubuntu.Components.Popups 1.3
import DocumentViewer 1.0
import QtQuick.Window 2.0
import Qt.labs.settings 1.0
import QtSystemInfo 5.0
import Ubuntu.Content 1.3

import "common"
import "common/loadComponent.js" as LoadComponent

MainView {
    id: mainView
    objectName: "mainView"

    // If device orientation is landscape and screen width is limited,
    // force hiding Unity 8 indicators panel.
    property bool fullscreen: commandLineProxy.fullscreen ||
                              (!desktopMode && isLandscape && narrowWindow) ||
                              pageStack.currentPage.hasOwnProperty("isPresentationMode")

    readonly property bool desktopMode: DocumentViewer.desktopMode

    readonly property bool narrowWindow: width < units.gu(51)
    readonly property bool wideWindow: width >= units.gu(80) && width < units.gu(120)
    readonly property bool veryWideWindow: width >= units.gu(120)
    readonly property bool isLandscape: Screen.orientation == Qt.LandscapeOrientation ||
                                        Screen.orientation == Qt.InvertedLandscapeOrientation

    applicationName: "sverzegnassi.pdfviewer"
    automaticOrientation: true

    width: units.gu(150)
    height: units.gu(75)

    function openDocument(path)  {
        if (path !== "") {
            console.log("Path of the document:", path)

            // If a document is already shown, pop() its page.
            while (pageStack.depth > 1)
                pageStack.pop();

            path = path.replace("file://", "")
                       .replace("document://", "");

            if (file.path === path) {
                // File has been already initialized, so just open the viewer
                LoadComponent.load(file.mimetype.name);

                return
            }

            file.path = path;
        }
    }

    function runUnknownTypeDialog() {
        mainView.showErrorDialog(i18n.tr("This file is not supported."));
    }

    function showErrorDialog(message) {
        PopupUtils.open(Qt.resolvedUrl("common/ErrorDialog.qml"),
                        mainView, { parent: mainView, text: message });
    }

    onFullscreenChanged: {
        if (mainView.fullscreen)
            window.visibility = Window.FullScreen
        else
            window.visibility = Window.Windowed
    }

    Component.onCompleted: {
        QuickUtils.mouseAttached = true;

        pageStack.push(Qt.resolvedUrl("documentPage/DocumentPage.qml"));

        // Open the document, if one has been specified.
        openDocument(commandLineProxy.documentFile);
    }

    File {
        id: file
        objectName: "file"

        onMimetypeChanged: LoadComponent.load(mimetype.name)
        onErrorChanged: {
            if (error == -1)
                mainView.showErrorDialog(i18n.tr("File does not exist."));
        }
    }

    PageStack { id: pageStack }

    Settings {
        id: sortSettings

        property int sortMode: 0    // 0 = by date, 1 = by name, 2 = by size
        property bool reverseOrder: false
    }

    property alias contentStore: contentStore
    ContentStore {
        id: contentStore
        scope: ContentScope.App
    }

    ScreenSaver {
        // Turn off screen saver during a full-screen presentation when the app is focused.
        screenSaverEnabled: !(Qt.application.active && pageStack.currentPage.isPresentationMode)
    }

    property bool nightModeEnabled: false
    layer.effect: NightModeShader {}
    layer.enabled: nightModeEnabled && (pageStack.depth > 1) && !pageStack.currentPage.isPresentationMode
}
